@@ -131,6 +131,10 @@ class Database:
             df['date'] = df['date'].astype(int)
             if 'T' in freq:
                 df['time'] = df['time'].astype(int)
+            else:
+                df['time'] = 0
+
+            df = df[['date', 'time', 'open', 'high', 'low', 'close', 'volume']]
 
             return df
     
